@@ -199,8 +199,7 @@
                  index_dtimes_data=as.integer(index.dtimes-1),
                  index_comptimes_data=as.integer(index.comptimes-1),
                  index_censtimes_data=as.integer(index.censtimes-1),
-                 X_data=as.double(X), # nxp
-                 Mt_data=as.double(as.numeric(n)),
+                 X_data=as.double(X),
                  plotnum=as.integer(plots),
                  type_test_num=as.integer(type.test.num),
                  KS=as.double(numeric(p)),
